aboutsummaryrefslogtreecommitdiffstats
path: root/activerecord/test
diff options
context:
space:
mode:
Diffstat (limited to 'activerecord/test')
-rw-r--r--activerecord/test/cases/attribute_methods_test.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/activerecord/test/cases/attribute_methods_test.rb b/activerecord/test/cases/attribute_methods_test.rb
index 06adb33ffc..7e3e204626 100644
--- a/activerecord/test/cases/attribute_methods_test.rb
+++ b/activerecord/test/cases/attribute_methods_test.rb
@@ -118,8 +118,8 @@ class AttributeMethodsTest < ActiveRecord::TestCase
def test_read_attributes_before_type_cast_on_datetime
developer = Developer.find(:first)
- if current_adapter?(:Mysql2Adapter)
- # Mysql2 keeps the value in Time instance
+ if current_adapter?(:Mysql2Adapter, :OracleAdapter)
+ # Mysql2 and Oracle adapters keep the value in Time instance
assert_equal developer.created_at.to_s(:db), developer.attributes_before_type_cast["created_at"].to_s(:db)
else
assert_equal developer.created_at.to_s(:db), developer.attributes_before_type_cast["created_at"].to_s